@@ -3,19 +3,18 @@
 This authentication backend can take public cloud API keys (US-1, US-2, EU-1), and will ask the
 user which child CID to authenticate against.
 """
-import os
 
-from typing import Dict, List, Optional
+from typing import Dict, Optional
 
+import click
 import keyring
-import pick
 
 from caracara import Client
 
 from falcon_toolkit.common.auth import AuthBackend
 from falcon_toolkit.common.auth_backends.utils import advanced_options_wizard
 from falcon_toolkit.common.constants import KEYRING_SERVICE_NAME
-from falcon_toolkit.common.utils import fancy_input
+from falcon_toolkit.common.utils import fancy_input, choose_cid
 
 
 class PublicCloudFlightControlParentCIDBackend(AuthBackend):
@@ -34,6 +33,8 @@ class PublicCloudFlightControlParentCIDBackend(AuthBackend):
         "party. This option is compatible with all of CrowdStrike's public cloud environments. "
         "For EU-1, US-1 and US-2, only a Client ID and Client Secret are required. For US "
         "GovCloud, set the Cloud Name to usgov1 within the additional options. "
+        "This option should be used only when you are connecting to a Parent CID; if you only have "
+        "keys for a child CID, use the Single CID authentication backend instead. "
         "NOTE: Each time you connect to a Flight Control CID you will be prompted on screen to "
         "choose a child CID to connect to. To skip this, set the environment variable "
         "FALCON_MSSP_CHILD_CID to the CID you want to connect to."
@@ -78,7 +79,7 @@ class PublicCloudFlightControlParentCIDBackend(AuthBackend):
 
     @client_secret.setter
     def client_secret(self, _client_secret: str):
-        """Store the client secret to the system secrets store."""
+        """Store the client secret in the system secrets store."""
         keyring.set_password(
             service_name=KEYRING_SERVICE_NAME,
             username=self.client_id,
@@ -92,15 +93,17 @@ class PublicCloudFlightControlParentCIDBackend(AuthBackend):
         keyring.
         """
         config: Dict[str, object] = {}
-        config['client_id']: str = self.client_id
-        config['cloud_name']: str = self.cloud_name
-        config['ssl_verify']: bool = self.ssl_verify
-        config['proxy']: Dict[str, str] = self.proxy
+        config["client_id"] = self.client_id
+        config["cloud_name"] = self.cloud_name
+        config["ssl_verify"] = self.ssl_verify
+        config["proxy"] = self.proxy
 
         return config
 
-    def authenticate(self) -> Client:
+    def authenticate(self, ctx: click.Context) -> Client:
         """Log the Toolkit into Falcon using the settings and keys configured at instance setup."""
+        chosen_cid_str = ctx.obj["cid"]
+
         parent_client = Client(
             client_id=self.client_id,
             client_secret=self.client_secret,
@@ -109,27 +112,39 @@ class PublicCloudFlightControlParentCIDBackend(AuthBackend):
             proxy=self.proxy,
         )
         child_cids = parent_client.flight_control.get_child_cids()
-        chosen_cid_str = os.environ.get("FALCON_MSSP_CHILD_CID")
-        if chosen_cid_str and chosen_cid_str.lower() in child_cids:
-            chosen_cid = parent_client.flight_control.get_child_cid_data(
-                cids=[chosen_cid_str]
-            )[chosen_cid_str]
-        else:
-            child_cids_data = parent_client.flight_control.get_child_cid_data(cids=child_cids)
 
-            options: List[pick.Option] = []
-            for child_cid_str, child_cid_data in child_cids_data.items():
-                child_cid_name = child_cid_data['name']
-                option_text = f"{child_cid_str}: {child_cid_name}"
-                option = pick.Option(label=option_text, value=child_cid_str)
-                options.append(option)
+        if chosen_cid_str and chosen_cid_str in child_cids:
+            click.echo(
+                click.style("Valid member CID ", fg="blue")
+                + click.style(chosen_cid_str, fg="blue", bold=True)
+                + click.style(" provided. Skipping CID selection.", fg="blue")
+            )
+        elif chosen_cid_str:
+            click.echo(click.style("An invalid CID was provided at the command line.", fg="red"))
+            click.echo("Please search for an alternative CID:")
+            # Blank out a bad value
+            chosen_cid_str = None
 
-            chosen_option, _ = pick.pick(options, "Please select a CID to connect to")
-            chosen_cid_str = chosen_option.value
-            chosen_cid = child_cids_data[chosen_cid_str]
+        if not chosen_cid_str:
+            if chosen_cid_str and chosen_cid_str.lower() in child_cids:
+                chosen_cid = parent_client.flight_control.get_child_cid_data(
+                    cids=[chosen_cid_str],
+                )[chosen_cid_str]
+            else:
+                child_cids_data = parent_client.flight_control.get_child_cid_data(cids=child_cids)
+                if not child_cids_data:
+                    raise RuntimeError(
+                        "No child CIDs accessible. Please check your API credentials."
+                    )
 
-        chosen_cid_name = chosen_cid['name']
-        print(f"Connecting to {chosen_cid_name}")
+                chosen_cid_str = choose_cid(
+                    cids=child_cids_data,
+                    prompt_text="MSSP Child CID Search",
+                )
+                chosen_cid = child_cids_data[chosen_cid_str]
+
+            chosen_cid_name = chosen_cid["name"]
+            print(f"Connecting to {chosen_cid_name}")
 
         client = Client(
             client_id=self.client_id,
