@@ -3,8 +3,10 @@
 This authentication backend can take public cloud API keys (US-1, US-2, EU-1), and will return
 an OAuth2 object suitable for authenticating with FalconPy.
 """
+
 from typing import Dict, Optional
 
+import click
 import keyring
 
 from caracara import Client
@@ -67,6 +69,7 @@ class PublicCloudSingleCIDBackend(AuthBackend):
 
     @client_secret.setter
     def client_secret(self, _client_secret: str):
+        """Store the client secret in the system secrets store."""
         keyring.set_password(
             service_name=KEYRING_SERVICE_NAME,
             username=self.client_id,
@@ -80,14 +83,14 @@ class PublicCloudSingleCIDBackend(AuthBackend):
         keyring.
         """
         config: Dict[str, object] = {}
-        config['client_id'] = self.client_id
-        config['cloud_name'] = self.cloud_name
-        config['ssl_verify'] = self.ssl_verify
-        config['proxy'] = self.proxy
+        config["client_id"] = self.client_id
+        config["cloud_name"] = self.cloud_name
+        config["ssl_verify"] = self.ssl_verify
+        config["proxy"] = self.proxy
 
         return config
 
-    def authenticate(self) -> Client:
+    def authenticate(self, ctx: click.Context) -> Client:
         """Log the Toolkit into Falcon using the settings and keys configured at instance setup."""
         client = Client(
             client_id=self.client_id,
