@@ -3,12 +3,13 @@
 This file contains tools to help with displaying data on the console in a user-friendly,
 colourful and/or helpful way.
 """
+
 import platform
 
 
-ESC = '\033'
-OSC = ESC + ']'
-ST = ESC + '\\'
+ESC = "\033"
+OSC = ESC + "]"
+ST = ESC + "\\"
 
 
 def build_hyperlink(target: str, text: str, link_id: str = None):
@@ -17,7 +18,7 @@ def build_hyperlink(target: str, text: str, link_id: str = None):
         id_str = "id=" + link_id
     else:
         id_str = ""
-    return f'{OSC}8;{id_str};{target}{ST}{text}{OSC}8;;{ST}'
+    return f"{OSC}8;{id_str};{target}{ST}{text}{OSC}8;;{ST}"
 
 
 def build_file_hyperlink(file_path: str, text: str, link_id: str = None):
@@ -27,7 +28,7 @@ def build_file_hyperlink(file_path: str, text: str, link_id: str = None):
     else:
         hostname = platform.node()
 
-    if file_path.startswith('/'):
+    if file_path.startswith("/"):
         file_path = file_path[1:]
 
     uri_file_path = f"file://{hostname}/{file_path}"
