@@ -3,6 +3,7 @@
 This file contains constants that are required to properly display and manage Prevention and
 Response policies within a Falcon tenant.
 """
+
 from typing import Union
 
 from caracara.modules.prevention_policies import PreventionPoliciesApiModule
@@ -29,7 +30,7 @@ POLICY_TYPES = [
 
 # Union type of all types of all Caracara modules providing policy data
 # They all expose a common API, so can be assumed to be one type where convenient
-PoliciesAPIModule = Union[
+PoliciesApiModule = Union[
     PreventionPoliciesApiModule,
     ResponsePoliciesApiModule,
 ]
