@@ -3,6 +3,7 @@
 This file contains the CLI options for the shell command, which allows a user to invoke a batch
 RTR shell with many connected systems at once.
 """
+
 import logging
 import logging.handlers
 import sys
@@ -16,6 +17,8 @@ from click_option_group import (
     MutuallyExclusiveOptionGroup,
 )
 
+from caracara.common.constants import OnlineState
+
 from falcon_toolkit.common.cli import (
     get_instance,
     parse_cli_filters,
@@ -24,26 +27,26 @@ from falcon_toolkit.shell.prompt import RTRPrompt
 
 
 @click.command(
-    name='shell',
-    help='Create a Real Time Response batch shell',
+    name="shell",
+    help="Create a Real Time Response batch shell",
 )
 @click.pass_context
 @optgroup.group(
     "Specify devices",
     cls=MutuallyExclusiveOptionGroup,
-    help="Choose no more than one method to choose systems to connect to"
+    help="Choose no more than one method to choose systems to connect to",
 )
 @optgroup.option(
-    '-d',
-    '--device-id-list',
-    'device_id_list',
+    "-d",
+    "--device-id-list",
+    "device_id_list",
     type=click.STRING,
     help="Specify a list of Device IDs (AIDs) to connect to, comma delimited",
 )
 @optgroup.option(
-    '-df',
-    '--device-id-file',
-    'device_id_file',
+    "-df",
+    "--device-id-file",
+    "device_id_file",
     type=click.STRING,
     help=(
         "Specify a list of Device IDs (AIDs) to connect to in an external file, one per line; "
@@ -51,29 +54,29 @@ from falcon_toolkit.shell.prompt import RTRPrompt
     ),
 )
 @optgroup.option(
-    '-f',
-    '--filter',
-    'filter_kv_strings',
+    "-f",
+    "--filter",
+    "filter_kv_strings",
     type=click.STRING,
     multiple=True,
     help="Filter hosts to connect to based on standard Falcon filters",
 )
 @optgroup.group(
     "RTR Connection Options",
-    help="General connection options for the Real Time Response (RTR) batch session."
+    help="General connection options for the Real Time Response (RTR) batch session.",
 )
 @optgroup.option(
-    '-q',
-    '--queueing',
+    "-q",
+    "--queueing",
     type=click.BOOL,
     is_flag=True,
     default=False,
     help="Enable RTR Queueing  (default: off)",
 )
 @optgroup.option(
-    '-s',
-    '--script',
-    'startup_script',
+    "-s",
+    "--script",
+    "startup_script",
     required=False,
     type=click.STRING,
     help=(
@@ -84,14 +87,14 @@ from falcon_toolkit.shell.prompt import RTRPrompt
     ),
 )
 @optgroup.option(
-    '-t',
-    '--timeout',
+    "-t",
+    "--timeout",
     type=click.INT,
     default=30,
     required=False,
     help="Set the timeout for RTR (default: 30s)",
 )
-def cli_shell(  # pylint: disable=too-many-arguments,too-many-locals
+def cli_shell(  # pylint: disable=too-many-arguments,too-many-locals,too-many-positional-arguments
     ctx: click.Context,
     device_id_list: str,
     device_id_file: str,
@@ -119,14 +122,20 @@ def cli_shell(  # pylint: disable=too-many-arguments,too-many-locals
     start the REPL command loop. This passes control over to the shell, via the Cmd2 library.
     """
     instance = get_instance(ctx)
-    client = instance.auth_backend.authenticate()
+    client = instance.auth_backend.authenticate(ctx)
+
+    # Show online hosts only if queueing is false
+    online_state = None if queueing else OnlineState.ONLINE
+    online_string = "" if queueing else "online "
 
     if filter_kv_strings:
-        click.echo(click.style(
-            "Connecting to all hosts that match the provided Falcon filters",
-            fg='magenta',
-            bold=True,
-        ))
+        click.echo(
+            click.style(
+                "Connecting to all hosts that match the provided Falcon filters",
+                fg="magenta",
+                bold=True,
+            )
+        )
         logging.info("Connecting to all hosts that match the provided Falcon filters")
 
         filters = parse_cli_filters(filter_kv_strings, client).get_fql()
@@ -134,13 +143,15 @@ def cli_shell(  # pylint: disable=too-many-arguments,too-many-locals
         click.echo(filters)
         logging.info(filters)
 
-        device_ids = client.hosts.get_device_ids(filters=filters)
+        device_ids = client.hosts.get_device_ids(filters=filters, online_state=online_state)
     elif device_id_list:
-        click.echo(click.style(
-            "Connecting to the device IDs provided on the command line",
-            fg='magenta',
-            bold=True,
-        ))
+        click.echo(
+            click.style(
+                "Connecting to the device IDs provided on the command line",
+                fg="magenta",
+                bold=True,
+            )
+        )
         logging.info("Connecting to the device IDs provided on the command line")
 
         device_ids = set()
@@ -149,34 +160,50 @@ def cli_shell(  # pylint: disable=too-many-arguments,too-many-locals
             if device_id:
                 device_ids.add(device_id)
 
-        device_ids = list(device_ids)
+        device_ids = client.hosts.filter_device_ids_by_online_state(
+            list(device_ids),
+            online_state=online_state,
+        )
     elif device_id_file:
-        click.echo(click.style(
-            "Connecting to the device IDs listed in a file",
-            fg='magenta',
-            bold=True,
-        ))
+        click.echo(
+            click.style(
+                "Connecting to the device IDs listed in a file",
+                fg="magenta",
+                bold=True,
+            )
+        )
         click.echo(click.style("File path: ", bold=True), nl=False)
         click.echo(device_id_file)
         logging.info("Connecting to the device IDs listed in %s", device_id_file)
 
-        with open(device_id_file, 'rt', encoding='ascii') as device_id_file_handle:
+        with open(device_id_file, "rt", encoding="ascii") as device_id_file_handle:
             device_ids = set()
             for line in device_id_file_handle:
                 line = line.strip()
                 if line:
                     device_ids.add(line)
-            device_ids = list(device_ids)
+            device_ids = client.hosts.filter_device_ids_by_online_state(
+                list(device_ids),
+                online_state=online_state,
+            )
     else:
-        click.echo(click.style(
-            "WARNING: Connecting to all hosts in the Falcon instance",
-            fg='yellow',
-        ))
-        logging.info("Connecting to all hosts in the Falcon instance")
-        device_ids = client.hosts.get_device_ids()
+        click.echo(
+            click.style(
+                f"WARNING: Connecting to all {online_string}hosts in the Falcon instance",
+                fg="yellow",
+            )
+        )
+        logging.info("Connecting to all %shosts in the Falcon instance", online_string)
+        device_ids = client.hosts.get_device_ids(online_state=online_state)
 
     if not device_ids:
-        click.echo(click.style("No devices match the provided filters", fg='red', bold=True))
+        click.echo(
+            click.style(
+                f"No {online_string}devices match the provided filters",
+                fg="red",
+                bold=True,
+            )
+        )
         sys.exit(1)
 
     device_count = len(device_ids)
@@ -184,7 +211,7 @@ def cli_shell(  # pylint: disable=too-many-arguments,too-many-locals
     logging.info("Connecting to %d device(s)", device_count)
     logging.debug(device_ids)
 
-    log_filename_base = ctx.obj['log_filename_base']
+    log_filename_base = ctx.obj["log_filename_base"]
     csv_filename = f"{log_filename_base}.csv"
 
     prompt = RTRPrompt(
